@@ -4,6 +4,7 @@
 #
 # prepares a staging directory with the requirements
 set -e
+set -x
 scriptdir=$(cd $(dirname $0) && pwd)
 
 # prepare staging directory
@@ -16,7 +17,7 @@ cp -f ${scriptdir}/src/* $PWD
 cp -f ${scriptdir}/test/* $PWD
 
 # install deps
-pip3 install -r requirements.txt -t .
+pip3 install --no-user -r requirements.txt -t .
 
 # run our tests
 exec python3 test.py $@
