@@ -10,11 +10,23 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IInspectable as _IInspectable_051e6ed8, IResolvable as _IResolvable_9ceae33e)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnKeyspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cassandra.CfnKeyspace"):
+class CfnKeyspace(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_cassandra.CfnKeyspace",
+):
     """A CloudFormation ``AWS::Cassandra::Keyspace``.
 
     see
@@ -22,7 +34,14 @@ class CfnKeyspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
     cloudformationResource:
     :cloudformationResource:: AWS::Cassandra::Keyspace
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, keyspace_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        keyspace_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::Cassandra::Keyspace``.
 
         :param scope: - scope in which this resource is defined.
@@ -35,7 +54,14 @@ class CfnKeyspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnKeyspace":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnKeyspace":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -50,7 +76,9 @@ class CfnKeyspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -64,7 +92,9 @@ class CfnKeyspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -96,9 +126,13 @@ class CfnKeyspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         jsii.set(self, "keyspaceName", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_cassandra.CfnKeyspaceProps", jsii_struct_bases=[], name_mapping={'keyspace_name': 'keyspaceName'})
-class CfnKeyspaceProps():
-    def __init__(self, *, keyspace_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_cassandra.CfnKeyspaceProps",
+    jsii_struct_bases=[],
+    name_mapping={"keyspace_name": "keyspaceName"},
+)
+class CfnKeyspaceProps:
+    def __init__(self, *, keyspace_name: typing.Optional[str] = None) -> None:
         """Properties for defining a ``AWS::Cassandra::Keyspace``.
 
         :param keyspace_name: ``AWS::Cassandra::Keyspace.KeyspaceName``.
@@ -106,9 +140,9 @@ class CfnKeyspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html
         """
-        self._values = {
-        }
-        if keyspace_name is not None: self._values["keyspace_name"] = keyspace_name
+        self._values = {}
+        if keyspace_name is not None:
+            self._values["keyspace_name"] = keyspace_name
 
     @builtins.property
     def keyspace_name(self) -> typing.Optional[str]:
@@ -117,7 +151,7 @@ class CfnKeyspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html#cfn-cassandra-keyspace-keyspacename
         """
-        return self._values.get('keyspace_name')
+        return self._values.get("keyspace_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -126,11 +160,17 @@ class CfnKeyspaceProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnKeyspaceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnKeyspaceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cassandra.CfnTable"):
+class CfnTable(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_cassandra.CfnTable",
+):
     """A CloudFormation ``AWS::Cassandra::Table``.
 
     see
@@ -138,7 +178,36 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
     cloudformationResource:
     :cloudformationResource:: AWS::Cassandra::Table
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, keyspace_name: str, partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]], billing_mode: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]]=None, clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]=None, regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]]=None, table_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        keyspace_name: str,
+        partition_key_columns: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
+        ],
+        billing_mode: typing.Optional[
+            typing.Union["BillingModeProperty", _IResolvable_9ceae33e]
+        ] = None,
+        clustering_key_columns: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ] = None,
+        regular_columns: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
+            ]
+        ] = None,
+        table_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::Cassandra::Table``.
 
         :param scope: - scope in which this resource is defined.
@@ -150,13 +219,27 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         :param regular_columns: ``AWS::Cassandra::Table.RegularColumns``.
         :param table_name: ``AWS::Cassandra::Table.TableName``.
         """
-        props = CfnTableProps(keyspace_name=keyspace_name, partition_key_columns=partition_key_columns, billing_mode=billing_mode, clustering_key_columns=clustering_key_columns, regular_columns=regular_columns, table_name=table_name)
+        props = CfnTableProps(
+            keyspace_name=keyspace_name,
+            partition_key_columns=partition_key_columns,
+            billing_mode=billing_mode,
+            clustering_key_columns=clustering_key_columns,
+            regular_columns=regular_columns,
+            table_name=table_name,
+        )
 
         jsii.create(CfnTable, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnTable":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnTable":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -171,7 +254,9 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -185,7 +270,9 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -218,7 +305,12 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
 
     @builtins.property
     @jsii.member(jsii_name="partitionKeyColumns")
-    def partition_key_columns(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]:
+    def partition_key_columns(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
+    ]:
         """``AWS::Cassandra::Table.PartitionKeyColumns``.
 
         see
@@ -227,12 +319,20 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         return jsii.get(self, "partitionKeyColumns")
 
     @partition_key_columns.setter
-    def partition_key_columns(self, value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]) -> None:
+    def partition_key_columns(
+        self,
+        value: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
+        ],
+    ) -> None:
         jsii.set(self, "partitionKeyColumns", value)
 
     @builtins.property
     @jsii.member(jsii_name="billingMode")
-    def billing_mode(self) -> typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]]:
+    def billing_mode(
+        self,
+    ) -> typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]]:
         """``AWS::Cassandra::Table.BillingMode``.
 
         see
@@ -241,12 +341,26 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         return jsii.get(self, "billingMode")
 
     @billing_mode.setter
-    def billing_mode(self, value: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]]) -> None:
+    def billing_mode(
+        self,
+        value: typing.Optional[
+            typing.Union["BillingModeProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
         jsii.set(self, "billingMode", value)
 
     @builtins.property
     @jsii.member(jsii_name="clusteringKeyColumns")
-    def clustering_key_columns(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
+    def clustering_key_columns(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]
+            ],
+        ]
+    ]:
         """``AWS::Cassandra::Table.ClusteringKeyColumns``.
 
         see
@@ -255,12 +369,29 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         return jsii.get(self, "clusteringKeyColumns")
 
     @clustering_key_columns.setter
-    def clustering_key_columns(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def clustering_key_columns(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "clusteringKeyColumns", value)
 
     @builtins.property
     @jsii.member(jsii_name="regularColumns")
-    def regular_columns(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]]:
+    def regular_columns(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
         """``AWS::Cassandra::Table.RegularColumns``.
 
         see
@@ -269,7 +400,15 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         return jsii.get(self, "regularColumns")
 
     @regular_columns.setter
-    def regular_columns(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def regular_columns(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "regularColumns", value)
 
     @builtins.property
@@ -286,9 +425,25 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
     def table_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "tableName", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_cassandra.CfnTable.BillingModeProperty", jsii_struct_bases=[], name_mapping={'mode': 'mode', 'provisioned_throughput': 'provisionedThroughput'})
-    class BillingModeProperty():
-        def __init__(self, *, mode: str, provisioned_throughput: typing.Optional[typing.Union["CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e]]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_cassandra.CfnTable.BillingModeProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "mode": "mode",
+            "provisioned_throughput": "provisionedThroughput",
+        },
+    )
+    class BillingModeProperty:
+        def __init__(
+            self,
+            *,
+            mode: str,
+            provisioned_throughput: typing.Optional[
+                typing.Union[
+                    "CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e
+                ]
+            ] = None,
+        ) -> None:
             """
             :param mode: ``CfnTable.BillingModeProperty.Mode``.
             :param provisioned_throughput: ``CfnTable.BillingModeProperty.ProvisionedThroughput``.
@@ -297,9 +452,10 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html
             """
             self._values = {
-                'mode': mode,
+                "mode": mode,
             }
-            if provisioned_throughput is not None: self._values["provisioned_throughput"] = provisioned_throughput
+            if provisioned_throughput is not None:
+                self._values["provisioned_throughput"] = provisioned_throughput
 
         @builtins.property
         def mode(self) -> str:
@@ -308,16 +464,22 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html#cfn-cassandra-table-billingmode-mode
             """
-            return self._values.get('mode')
+            return self._values.get("mode")
 
         @builtins.property
-        def provisioned_throughput(self) -> typing.Optional[typing.Union["CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e]]:
+        def provisioned_throughput(
+            self,
+        ) -> typing.Optional[
+            typing.Union[
+                "CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e
+            ]
+        ]:
             """``CfnTable.BillingModeProperty.ProvisionedThroughput``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html#cfn-cassandra-table-billingmode-provisionedthroughput
             """
-            return self._values.get('provisioned_throughput')
+            return self._values.get("provisioned_throughput")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -326,12 +488,22 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'BillingModeProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "BillingModeProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_cassandra.CfnTable.ClusteringKeyColumnProperty", jsii_struct_bases=[], name_mapping={'column': 'column', 'order_by': 'orderBy'})
-    class ClusteringKeyColumnProperty():
-        def __init__(self, *, column: typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e], order_by: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_cassandra.CfnTable.ClusteringKeyColumnProperty",
+        jsii_struct_bases=[],
+        name_mapping={"column": "column", "order_by": "orderBy"},
+    )
+    class ClusteringKeyColumnProperty:
+        def __init__(
+            self,
+            *,
+            column: typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e],
+            order_by: typing.Optional[str] = None,
+        ) -> None:
             """
             :param column: ``CfnTable.ClusteringKeyColumnProperty.Column``.
             :param order_by: ``CfnTable.ClusteringKeyColumnProperty.OrderBy``.
@@ -340,18 +512,21 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html
             """
             self._values = {
-                'column': column,
+                "column": column,
             }
-            if order_by is not None: self._values["order_by"] = order_by
+            if order_by is not None:
+                self._values["order_by"] = order_by
 
         @builtins.property
-        def column(self) -> typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]:
+        def column(
+            self,
+        ) -> typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]:
             """``CfnTable.ClusteringKeyColumnProperty.Column``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html#cfn-cassandra-table-clusteringkeycolumn-column
             """
-            return self._values.get('column')
+            return self._values.get("column")
 
         @builtins.property
         def order_by(self) -> typing.Optional[str]:
@@ -360,7 +535,7 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html#cfn-cassandra-table-clusteringkeycolumn-orderby
             """
-            return self._values.get('order_by')
+            return self._values.get("order_by")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -369,11 +544,16 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'ClusteringKeyColumnProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "ClusteringKeyColumnProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_cassandra.CfnTable.ColumnProperty", jsii_struct_bases=[], name_mapping={'column_name': 'columnName', 'column_type': 'columnType'})
-    class ColumnProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_cassandra.CfnTable.ColumnProperty",
+        jsii_struct_bases=[],
+        name_mapping={"column_name": "columnName", "column_type": "columnType"},
+    )
+    class ColumnProperty:
         def __init__(self, *, column_name: str, column_type: str) -> None:
             """
             :param column_name: ``CfnTable.ColumnProperty.ColumnName``.
@@ -383,8 +563,8 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html
             """
             self._values = {
-                'column_name': column_name,
-                'column_type': column_type,
+                "column_name": column_name,
+                "column_type": column_type,
             }
 
         @builtins.property
@@ -394,7 +574,7 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html#cfn-cassandra-table-column-columnname
             """
-            return self._values.get('column_name')
+            return self._values.get("column_name")
 
         @builtins.property
         def column_type(self) -> str:
@@ -403,7 +583,7 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html#cfn-cassandra-table-column-columntype
             """
-            return self._values.get('column_type')
+            return self._values.get("column_type")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -412,12 +592,22 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'ColumnProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "ColumnProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_cassandra.CfnTable.ProvisionedThroughputProperty", jsii_struct_bases=[], name_mapping={'read_capacity_units': 'readCapacityUnits', 'write_capacity_units': 'writeCapacityUnits'})
-    class ProvisionedThroughputProperty():
-        def __init__(self, *, read_capacity_units: jsii.Number, write_capacity_units: jsii.Number) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_cassandra.CfnTable.ProvisionedThroughputProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "read_capacity_units": "readCapacityUnits",
+            "write_capacity_units": "writeCapacityUnits",
+        },
+    )
+    class ProvisionedThroughputProperty:
+        def __init__(
+            self, *, read_capacity_units: jsii.Number, write_capacity_units: jsii.Number
+        ) -> None:
             """
             :param read_capacity_units: ``CfnTable.ProvisionedThroughputProperty.ReadCapacityUnits``.
             :param write_capacity_units: ``CfnTable.ProvisionedThroughputProperty.WriteCapacityUnits``.
@@ -426,8 +616,8 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html
             """
             self._values = {
-                'read_capacity_units': read_capacity_units,
-                'write_capacity_units': write_capacity_units,
+                "read_capacity_units": read_capacity_units,
+                "write_capacity_units": write_capacity_units,
             }
 
         @builtins.property
@@ -437,7 +627,7 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html#cfn-cassandra-table-provisionedthroughput-readcapacityunits
             """
-            return self._values.get('read_capacity_units')
+            return self._values.get("read_capacity_units")
 
         @builtins.property
         def write_capacity_units(self) -> jsii.Number:
@@ -446,7 +636,7 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html#cfn-cassandra-table-provisionedthroughput-writecapacityunits
             """
-            return self._values.get('write_capacity_units')
+            return self._values.get("write_capacity_units")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -455,13 +645,55 @@ class CfnTable(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'ProvisionedThroughputProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "ProvisionedThroughputProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_cassandra.CfnTableProps", jsii_struct_bases=[], name_mapping={'keyspace_name': 'keyspaceName', 'partition_key_columns': 'partitionKeyColumns', 'billing_mode': 'billingMode', 'clustering_key_columns': 'clusteringKeyColumns', 'regular_columns': 'regularColumns', 'table_name': 'tableName'})
-class CfnTableProps():
-    def __init__(self, *, keyspace_name: str, partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]], billing_mode: typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]]=None, clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]=None, regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]]=None, table_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_cassandra.CfnTableProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "keyspace_name": "keyspaceName",
+        "partition_key_columns": "partitionKeyColumns",
+        "billing_mode": "billingMode",
+        "clustering_key_columns": "clusteringKeyColumns",
+        "regular_columns": "regularColumns",
+        "table_name": "tableName",
+    },
+)
+class CfnTableProps:
+    def __init__(
+        self,
+        *,
+        keyspace_name: str,
+        partition_key_columns: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]],
+        ],
+        billing_mode: typing.Optional[
+            typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]
+        ] = None,
+        clustering_key_columns: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ] = None,
+        regular_columns: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ] = None,
+        table_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Cassandra::Table``.
 
         :param keyspace_name: ``AWS::Cassandra::Table.KeyspaceName``.
@@ -475,13 +707,17 @@ class CfnTableProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html
         """
         self._values = {
-            'keyspace_name': keyspace_name,
-            'partition_key_columns': partition_key_columns,
+            "keyspace_name": keyspace_name,
+            "partition_key_columns": partition_key_columns,
         }
-        if billing_mode is not None: self._values["billing_mode"] = billing_mode
-        if clustering_key_columns is not None: self._values["clustering_key_columns"] = clustering_key_columns
-        if regular_columns is not None: self._values["regular_columns"] = regular_columns
-        if table_name is not None: self._values["table_name"] = table_name
+        if billing_mode is not None:
+            self._values["billing_mode"] = billing_mode
+        if clustering_key_columns is not None:
+            self._values["clustering_key_columns"] = clustering_key_columns
+        if regular_columns is not None:
+            self._values["regular_columns"] = regular_columns
+        if table_name is not None:
+            self._values["table_name"] = table_name
 
     @builtins.property
     def keyspace_name(self) -> str:
@@ -490,43 +726,70 @@ class CfnTableProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-keyspacename
         """
-        return self._values.get('keyspace_name')
+        return self._values.get("keyspace_name")
 
     @builtins.property
-    def partition_key_columns(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]:
+    def partition_key_columns(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]],
+    ]:
         """``AWS::Cassandra::Table.PartitionKeyColumns``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-partitionkeycolumns
         """
-        return self._values.get('partition_key_columns')
+        return self._values.get("partition_key_columns")
 
     @builtins.property
-    def billing_mode(self) -> typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]]:
+    def billing_mode(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::Cassandra::Table.BillingMode``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-billingmode
         """
-        return self._values.get('billing_mode')
+        return self._values.get("billing_mode")
 
     @builtins.property
-    def clustering_key_columns(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
+    def clustering_key_columns(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union[
+                    "CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e
+                ]
+            ],
+        ]
+    ]:
         """``AWS::Cassandra::Table.ClusteringKeyColumns``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-clusteringkeycolumns
         """
-        return self._values.get('clustering_key_columns')
+        return self._values.get("clustering_key_columns")
 
     @builtins.property
-    def regular_columns(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]]:
+    def regular_columns(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
         """``AWS::Cassandra::Table.RegularColumns``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-regularcolumns
         """
-        return self._values.get('regular_columns')
+        return self._values.get("regular_columns")
 
     @builtins.property
     def table_name(self) -> typing.Optional[str]:
@@ -535,7 +798,7 @@ class CfnTableProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-tablename
         """
-        return self._values.get('table_name')
+        return self._values.get("table_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -544,7 +807,9 @@ class CfnTableProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnTableProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnTableProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
