@@ -33,6 +33,7 @@ from ..aws_route53 import IHostedZone as _IHostedZone_59ffab76
     name_mapping={
         "domain_name": "domainName",
         "subject_alternative_names": "subjectAlternativeNames",
+        "validation": "validation",
         "validation_domains": "validationDomains",
         "validation_method": "validationMethod",
     },
@@ -43,6 +44,7 @@ class CertificateProps:
         *,
         domain_name: str,
         subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation: typing.Optional["CertificateValidation"] = None,
         validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
     ) -> None:
@@ -50,6 +52,7 @@ class CertificateProps:
 
         :param domain_name: Fully-qualified domain name to request a certificate for. May contain wildcards, such as ``*.domain.com``.
         :param subject_alternative_names: Alternative domain names on your certificate. Use this to register alternative domain names that represent the same site. Default: - No additional FQDNs will be included as alternative domain names.
+        :param validation: How to validate this certifcate. Default: CertificateValidation.fromEmail()
         :param validation_domains: What validation domain to use for every requested domain. Has to be a superdomain of the requested domain. Default: - Apex domain is used for every domain that's not overridden.
         :param validation_method: Validation method used to assert domain ownership. Default: ValidationMethod.EMAIL
 
@@ -61,6 +64,8 @@ class CertificateProps:
         }
         if subject_alternative_names is not None:
             self._values["subject_alternative_names"] = subject_alternative_names
+        if validation is not None:
+            self._values["validation"] = validation
         if validation_domains is not None:
             self._values["validation_domains"] = validation_domains
         if validation_method is not None:
@@ -91,6 +96,18 @@ class CertificateProps:
         """
         return self._values.get("subject_alternative_names")
 
+    @builtins.property
+    def validation(self) -> typing.Optional["CertificateValidation"]:
+        """How to validate this certifcate.
+
+        default
+        :default: CertificateValidation.fromEmail()
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("validation")
+
     @builtins.property
     def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
         """What validation domain to use for every requested domain.
@@ -100,8 +117,11 @@ class CertificateProps:
         default
         :default: - Apex domain is used for every domain that's not overridden.
 
+        deprecated
+        :deprecated: use ``validation`` instead.
+
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return self._values.get("validation_domains")
 
@@ -112,8 +132,11 @@ class CertificateProps:
         default
         :default: ValidationMethod.EMAIL
 
+        deprecated
+        :deprecated: use ``validation`` instead.
+
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return self._values.get("validation_method")
 
@@ -129,6 +152,200 @@ class CertificateProps:
         )
 
 
+class CertificateValidation(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_certificatemanager.CertificateValidation",
+):
+    """How to validate a certificate.
+
+    stability
+    :stability: experimental
+    """
+
+    @jsii.member(jsii_name="fromDns")
+    @builtins.classmethod
+    def from_dns(
+        cls, hosted_zone: typing.Optional[_IHostedZone_59ffab76] = None
+    ) -> "CertificateValidation":
+        """Validate the certifcate with DNS.
+
+        IMPORTANT: If ``hostedZone`` is not specified, DNS records must be added
+        manually and the stack will not complete creating until the records are
+        added.
+
+        :param hosted_zone: the hosted zone where DNS records must be created.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromDns", [hosted_zone])
+
+    @jsii.member(jsii_name="fromDnsMultiZone")
+    @builtins.classmethod
+    def from_dns_multi_zone(
+        cls, hosted_zones: typing.Mapping[str, _IHostedZone_59ffab76]
+    ) -> "CertificateValidation":
+        """Validate the certifcate with automatically created DNS records in multiple Amazon Route 53 hosted zones.
+
+        :param hosted_zones: a map of hosted zones where DNS records must be created for the domains in the certificate.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromDnsMultiZone", [hosted_zones])
+
+    @jsii.member(jsii_name="fromEmail")
+    @builtins.classmethod
+    def from_email(
+        cls, validation_domains: typing.Optional[typing.Mapping[str, str]] = None
+    ) -> "CertificateValidation":
+        """Validate the certifcate with Email.
+
+        IMPORTANT: if you are creating a certificate as part of your stack, the stack
+        will not complete creating until you read and follow the instructions in the
+        email that you will receive.
+
+        ACM will send validation emails to the following addresses:
+
+        admin@domain.com
+        administrator@domain.com
+        hostmaster@domain.com
+        postmaster@domain.com
+        webmaster@domain.com
+
+        For every domain that you register.
+
+        :param validation_domains: a map of validation domains to use for domains in the certificate.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromEmail", [validation_domains])
+
+    @builtins.property
+    @jsii.member(jsii_name="method")
+    def method(self) -> "ValidationMethod":
+        """The validation method.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "method")
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "CertificationValidationProps":
+        """Certification validation properties.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "props")
+
+
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_certificatemanager.CertificationValidationProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "hosted_zone": "hostedZone",
+        "hosted_zones": "hostedZones",
+        "method": "method",
+        "validation_domains": "validationDomains",
+    },
+)
+class CertificationValidationProps:
+    def __init__(
+        self,
+        *,
+        hosted_zone: typing.Optional[_IHostedZone_59ffab76] = None,
+        hosted_zones: typing.Optional[
+            typing.Mapping[str, _IHostedZone_59ffab76]
+        ] = None,
+        method: typing.Optional["ValidationMethod"] = None,
+        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+    ) -> None:
+        """Properties for certificate validation.
+
+        :param hosted_zone: Hosted zone to use for DNS validation. Default: - use email validation
+        :param hosted_zones: A map of hosted zones to use for DNS validation. Default: - use ``hostedZone``
+        :param method: Validation method. Default: ValidationMethod.EMAIL
+        :param validation_domains: Validation domains to use for email validation. Default: - Apex domain
+
+        stability
+        :stability: experimental
+        """
+        self._values = {}
+        if hosted_zone is not None:
+            self._values["hosted_zone"] = hosted_zone
+        if hosted_zones is not None:
+            self._values["hosted_zones"] = hosted_zones
+        if method is not None:
+            self._values["method"] = method
+        if validation_domains is not None:
+            self._values["validation_domains"] = validation_domains
+
+    @builtins.property
+    def hosted_zone(self) -> typing.Optional[_IHostedZone_59ffab76]:
+        """Hosted zone to use for DNS validation.
+
+        default
+        :default: - use email validation
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("hosted_zone")
+
+    @builtins.property
+    def hosted_zones(
+        self,
+    ) -> typing.Optional[typing.Mapping[str, _IHostedZone_59ffab76]]:
+        """A map of hosted zones to use for DNS validation.
+
+        default
+        :default: - use ``hostedZone``
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("hosted_zones")
+
+    @builtins.property
+    def method(self) -> typing.Optional["ValidationMethod"]:
+        """Validation method.
+
+        default
+        :default: ValidationMethod.EMAIL
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("method")
+
+    @builtins.property
+    def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
+        """Validation domains to use for email validation.
+
+        default
+        :default: - Apex domain
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("validation_domains")
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "CertificationValidationProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(_IInspectable_051e6ed8)
 class CfnCertificate(
     _CfnResource_7760e8e4,
@@ -598,6 +815,7 @@ class CfnCertificateProps:
     name_mapping={
         "domain_name": "domainName",
         "subject_alternative_names": "subjectAlternativeNames",
+        "validation": "validation",
         "validation_domains": "validationDomains",
         "validation_method": "validationMethod",
         "hosted_zone": "hostedZone",
@@ -612,6 +830,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         *,
         domain_name: str,
         subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation: typing.Optional["CertificateValidation"] = None,
         validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
         hosted_zone: _IHostedZone_59ffab76,
@@ -623,6 +842,7 @@ class DnsValidatedCertificateProps(CertificateProps):
 
         :param domain_name: Fully-qualified domain name to request a certificate for. May contain wildcards, such as ``*.domain.com``.
         :param subject_alternative_names: Alternative domain names on your certificate. Use this to register alternative domain names that represent the same site. Default: - No additional FQDNs will be included as alternative domain names.
+        :param validation: How to validate this certifcate. Default: CertificateValidation.fromEmail()
         :param validation_domains: What validation domain to use for every requested domain. Has to be a superdomain of the requested domain. Default: - Apex domain is used for every domain that's not overridden.
         :param validation_method: Validation method used to assert domain ownership. Default: ValidationMethod.EMAIL
         :param hosted_zone: Route 53 Hosted Zone used to perform DNS validation of the request. The zone must be authoritative for the domain name specified in the Certificate Request.
@@ -639,6 +859,8 @@ class DnsValidatedCertificateProps(CertificateProps):
         }
         if subject_alternative_names is not None:
             self._values["subject_alternative_names"] = subject_alternative_names
+        if validation is not None:
+            self._values["validation"] = validation
         if validation_domains is not None:
             self._values["validation_domains"] = validation_domains
         if validation_method is not None:
@@ -675,6 +897,18 @@ class DnsValidatedCertificateProps(CertificateProps):
         """
         return self._values.get("subject_alternative_names")
 
+    @builtins.property
+    def validation(self) -> typing.Optional["CertificateValidation"]:
+        """How to validate this certifcate.
+
+        default
+        :default: CertificateValidation.fromEmail()
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("validation")
+
     @builtins.property
     def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
         """What validation domain to use for every requested domain.
@@ -684,8 +918,11 @@ class DnsValidatedCertificateProps(CertificateProps):
         default
         :default: - Apex domain is used for every domain that's not overridden.
 
+        deprecated
+        :deprecated: use ``validation`` instead.
+
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return self._values.get("validation_domains")
 
@@ -696,8 +933,11 @@ class DnsValidatedCertificateProps(CertificateProps):
         default
         :default: ValidationMethod.EMAIL
 
+        deprecated
+        :deprecated: use ``validation`` instead.
+
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return self._values.get("validation_method")
 
@@ -850,20 +1090,6 @@ class Certificate(
 ):
     """A certificate managed by AWS Certificate Manager.
 
-    IMPORTANT: if you are creating a certificate as part of your stack, the stack
-    will not complete creating until you read and follow the instructions in the
-    email that you will receive.
-
-    ACM will send validation emails to the following addresses:
-
-    admin@domain.com
-    administrator@domain.com
-    hostmaster@domain.com
-    postmaster@domain.com
-    webmaster@domain.com
-
-    For every domain that you register.
-
     stability
     :stability: experimental
     """
@@ -875,6 +1101,7 @@ class Certificate(
         *,
         domain_name: str,
         subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation: typing.Optional["CertificateValidation"] = None,
         validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
     ) -> None:
@@ -883,6 +1110,7 @@ class Certificate(
         :param id: -
         :param domain_name: Fully-qualified domain name to request a certificate for. May contain wildcards, such as ``*.domain.com``.
         :param subject_alternative_names: Alternative domain names on your certificate. Use this to register alternative domain names that represent the same site. Default: - No additional FQDNs will be included as alternative domain names.
+        :param validation: How to validate this certifcate. Default: CertificateValidation.fromEmail()
         :param validation_domains: What validation domain to use for every requested domain. Has to be a superdomain of the requested domain. Default: - Apex domain is used for every domain that's not overridden.
         :param validation_method: Validation method used to assert domain ownership. Default: ValidationMethod.EMAIL
 
@@ -892,6 +1120,7 @@ class Certificate(
         props = CertificateProps(
             domain_name=domain_name,
             subject_alternative_names=subject_alternative_names,
+            validation=validation,
             validation_domains=validation_domains,
             validation_method=validation_method,
         )
@@ -953,6 +1182,7 @@ class DnsValidatedCertificate(
         route53_endpoint: typing.Optional[str] = None,
         domain_name: str,
         subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation: typing.Optional["CertificateValidation"] = None,
         validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
     ) -> None:
@@ -965,6 +1195,7 @@ class DnsValidatedCertificate(
         :param route53_endpoint: An endpoint of Route53 service, which is not necessary as AWS SDK could figure out the right endpoints for most regions, but for some regions such as those in aws-cn partition, the default endpoint is not working now, hence the right endpoint need to be specified through this prop. Route53 is not been offically launched in China, it is only available for AWS internal accounts now. To make DnsValidatedCertificate work for internal accounts now, a special endpoint needs to be provided. Default: - The AWS SDK will determine the Route53 endpoint to use based on region
         :param domain_name: Fully-qualified domain name to request a certificate for. May contain wildcards, such as ``*.domain.com``.
         :param subject_alternative_names: Alternative domain names on your certificate. Use this to register alternative domain names that represent the same site. Default: - No additional FQDNs will be included as alternative domain names.
+        :param validation: How to validate this certifcate. Default: CertificateValidation.fromEmail()
         :param validation_domains: What validation domain to use for every requested domain. Has to be a superdomain of the requested domain. Default: - Apex domain is used for every domain that's not overridden.
         :param validation_method: Validation method used to assert domain ownership. Default: ValidationMethod.EMAIL
 
@@ -978,6 +1209,7 @@ class DnsValidatedCertificate(
             route53_endpoint=route53_endpoint,
             domain_name=domain_name,
             subject_alternative_names=subject_alternative_names,
+            validation=validation,
             validation_domains=validation_domains,
             validation_method=validation_method,
         )
@@ -1010,6 +1242,8 @@ class DnsValidatedCertificate(
 __all__ = [
     "Certificate",
     "CertificateProps",
+    "CertificateValidation",
+    "CertificationValidationProps",
     "CfnCertificate",
     "CfnCertificateProps",
     "DnsValidatedCertificate",
