@@ -10,13 +10,33 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a, Resource as _Resource_884d0774, IResource as _IResource_72f7ee7e)
-from ..aws_codecommit import (IRepository as _IRepository_91f381de)
-from ..aws_ec2 import (IVpc as _IVpc_3795853f, InstanceType as _InstanceType_85a97b30, SubnetSelection as _SubnetSelection_36a13cd6)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+    Resource as _Resource_884d0774,
+    IResource as _IResource_72f7ee7e,
+)
+from ..aws_codecommit import IRepository as _IRepository_91f381de
+from ..aws_ec2 import (
+    IVpc as _IVpc_3795853f,
+    InstanceType as _InstanceType_85a97b30,
+    SubnetSelection as _SubnetSelection_36a13cd6,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cloud9.CfnEnvironmentEC2"):
+class CfnEnvironmentEC2(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_cloud9.CfnEnvironmentEC2",
+):
     """A CloudFormation ``AWS::Cloud9::EnvironmentEC2``.
 
     see
@@ -24,7 +44,27 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
     cloudformationResource:
     :cloudformationResource:: AWS::Cloud9::EnvironmentEC2
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, instance_type: str, automatic_stop_time_minutes: typing.Optional[jsii.Number]=None, connection_type: typing.Optional[str]=None, description: typing.Optional[str]=None, name: typing.Optional[str]=None, owner_arn: typing.Optional[str]=None, repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]]=None, subnet_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        instance_type: str,
+        automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+        connection_type: typing.Optional[str] = None,
+        description: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        owner_arn: typing.Optional[str] = None,
+        repositories: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]],
+            ]
+        ] = None,
+        subnet_id: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Create a new ``AWS::Cloud9::EnvironmentEC2``.
 
         :param scope: - scope in which this resource is defined.
@@ -39,13 +79,30 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         :param subnet_id: ``AWS::Cloud9::EnvironmentEC2.SubnetId``.
         :param tags: ``AWS::Cloud9::EnvironmentEC2.Tags``.
         """
-        props = CfnEnvironmentEC2Props(instance_type=instance_type, automatic_stop_time_minutes=automatic_stop_time_minutes, connection_type=connection_type, description=description, name=name, owner_arn=owner_arn, repositories=repositories, subnet_id=subnet_id, tags=tags)
+        props = CfnEnvironmentEC2Props(
+            instance_type=instance_type,
+            automatic_stop_time_minutes=automatic_stop_time_minutes,
+            connection_type=connection_type,
+            description=description,
+            name=name,
+            owner_arn=owner_arn,
+            repositories=repositories,
+            subnet_id=subnet_id,
+            tags=tags,
+        )
 
         jsii.create(CfnEnvironmentEC2, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnEnvironmentEC2":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnEnvironmentEC2":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -60,7 +117,9 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -74,7 +133,9 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -205,7 +266,14 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
 
     @builtins.property
     @jsii.member(jsii_name="repositories")
-    def repositories(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]]:
+    def repositories(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
         """``AWS::Cloud9::EnvironmentEC2.Repositories``.
 
         see
@@ -214,7 +282,15 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "repositories")
 
     @repositories.setter
-    def repositories(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def repositories(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "repositories", value)
 
     @builtins.property
@@ -231,8 +307,15 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
     def subnet_id(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "subnetId", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_cloud9.CfnEnvironmentEC2.RepositoryProperty", jsii_struct_bases=[], name_mapping={'path_component': 'pathComponent', 'repository_url': 'repositoryUrl'})
-    class RepositoryProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_cloud9.CfnEnvironmentEC2.RepositoryProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "path_component": "pathComponent",
+            "repository_url": "repositoryUrl",
+        },
+    )
+    class RepositoryProperty:
         def __init__(self, *, path_component: str, repository_url: str) -> None:
             """
             :param path_component: ``CfnEnvironmentEC2.RepositoryProperty.PathComponent``.
@@ -242,8 +325,8 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html
             """
             self._values = {
-                'path_component': path_component,
-                'repository_url': repository_url,
+                "path_component": path_component,
+                "repository_url": repository_url,
             }
 
         @builtins.property
@@ -253,7 +336,7 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             """
-            return self._values.get('path_component')
+            return self._values.get("path_component")
 
         @builtins.property
         def repository_url(self) -> str:
@@ -262,7 +345,7 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             """
-            return self._values.get('repository_url')
+            return self._values.get("repository_url")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -271,13 +354,49 @@ class CfnEnvironmentEC2(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'RepositoryProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "RepositoryProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_cloud9.CfnEnvironmentEC2Props", jsii_struct_bases=[], name_mapping={'instance_type': 'instanceType', 'automatic_stop_time_minutes': 'automaticStopTimeMinutes', 'connection_type': 'connectionType', 'description': 'description', 'name': 'name', 'owner_arn': 'ownerArn', 'repositories': 'repositories', 'subnet_id': 'subnetId', 'tags': 'tags'})
-class CfnEnvironmentEC2Props():
-    def __init__(self, *, instance_type: str, automatic_stop_time_minutes: typing.Optional[jsii.Number]=None, connection_type: typing.Optional[str]=None, description: typing.Optional[str]=None, name: typing.Optional[str]=None, owner_arn: typing.Optional[str]=None, repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]]=None, subnet_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_cloud9.CfnEnvironmentEC2Props",
+    jsii_struct_bases=[],
+    name_mapping={
+        "instance_type": "instanceType",
+        "automatic_stop_time_minutes": "automaticStopTimeMinutes",
+        "connection_type": "connectionType",
+        "description": "description",
+        "name": "name",
+        "owner_arn": "ownerArn",
+        "repositories": "repositories",
+        "subnet_id": "subnetId",
+        "tags": "tags",
+    },
+)
+class CfnEnvironmentEC2Props:
+    def __init__(
+        self,
+        *,
+        instance_type: str,
+        automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+        connection_type: typing.Optional[str] = None,
+        description: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        owner_arn: typing.Optional[str] = None,
+        repositories: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ] = None,
+        subnet_id: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Cloud9::EnvironmentEC2``.
 
         :param instance_type: ``AWS::Cloud9::EnvironmentEC2.InstanceType``.
@@ -294,16 +413,24 @@ class CfnEnvironmentEC2Props():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
         """
         self._values = {
-            'instance_type': instance_type,
+            "instance_type": instance_type,
         }
-        if automatic_stop_time_minutes is not None: self._values["automatic_stop_time_minutes"] = automatic_stop_time_minutes
-        if connection_type is not None: self._values["connection_type"] = connection_type
-        if description is not None: self._values["description"] = description
-        if name is not None: self._values["name"] = name
-        if owner_arn is not None: self._values["owner_arn"] = owner_arn
-        if repositories is not None: self._values["repositories"] = repositories
-        if subnet_id is not None: self._values["subnet_id"] = subnet_id
-        if tags is not None: self._values["tags"] = tags
+        if automatic_stop_time_minutes is not None:
+            self._values["automatic_stop_time_minutes"] = automatic_stop_time_minutes
+        if connection_type is not None:
+            self._values["connection_type"] = connection_type
+        if description is not None:
+            self._values["description"] = description
+        if name is not None:
+            self._values["name"] = name
+        if owner_arn is not None:
+            self._values["owner_arn"] = owner_arn
+        if repositories is not None:
+            self._values["repositories"] = repositories
+        if subnet_id is not None:
+            self._values["subnet_id"] = subnet_id
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def instance_type(self) -> str:
@@ -312,7 +439,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
         """
-        return self._values.get('instance_type')
+        return self._values.get("instance_type")
 
     @builtins.property
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
@@ -321,7 +448,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
         """
-        return self._values.get('automatic_stop_time_minutes')
+        return self._values.get("automatic_stop_time_minutes")
 
     @builtins.property
     def connection_type(self) -> typing.Optional[str]:
@@ -330,7 +457,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-connectiontype
         """
-        return self._values.get('connection_type')
+        return self._values.get("connection_type")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -339,7 +466,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def name(self) -> typing.Optional[str]:
@@ -348,7 +475,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def owner_arn(self) -> typing.Optional[str]:
@@ -357,16 +484,27 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
         """
-        return self._values.get('owner_arn')
+        return self._values.get("owner_arn")
 
     @builtins.property
-    def repositories(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]]:
+    def repositories(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union[
+                    "CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e
+                ]
+            ],
+        ]
+    ]:
         """``AWS::Cloud9::EnvironmentEC2.Repositories``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         """
-        return self._values.get('repositories')
+        return self._values.get("repositories")
 
     @builtins.property
     def subnet_id(self) -> typing.Optional[str]:
@@ -375,7 +513,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
         """
-        return self._values.get('subnet_id')
+        return self._values.get("subnet_id")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -384,7 +522,7 @@ class CfnEnvironmentEC2Props():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -393,18 +531,25 @@ class CfnEnvironmentEC2Props():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnEnvironmentEC2Props(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnEnvironmentEC2Props(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-class CloneRepository(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cloud9.CloneRepository"):
+class CloneRepository(
+    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cloud9.CloneRepository"
+):
     """The class for different repository providers.
 
     stability
     :stability: experimental
     """
+
     @jsii.member(jsii_name="fromCodeCommit")
     @builtins.classmethod
-    def from_code_commit(cls, repository: _IRepository_91f381de, path: str) -> "CloneRepository":
+    def from_code_commit(
+        cls, repository: _IRepository_91f381de, path: str
+    ) -> "CloneRepository":
         """import repository to cloud9 environment from AWS CodeCommit.
 
         :param repository: the codecommit repository to clone from.
@@ -434,9 +579,29 @@ class CloneRepository(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws
         return jsii.get(self, "repositoryUrl")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_cloud9.Ec2EnvironmentProps", jsii_struct_bases=[], name_mapping={'vpc': 'vpc', 'cloned_repositories': 'clonedRepositories', 'description': 'description', 'ec2_environment_name': 'ec2EnvironmentName', 'instance_type': 'instanceType', 'subnet_selection': 'subnetSelection'})
-class Ec2EnvironmentProps():
-    def __init__(self, *, vpc: _IVpc_3795853f, cloned_repositories: typing.Optional[typing.List["CloneRepository"]]=None, description: typing.Optional[str]=None, ec2_environment_name: typing.Optional[str]=None, instance_type: typing.Optional[_InstanceType_85a97b30]=None, subnet_selection: typing.Optional[_SubnetSelection_36a13cd6]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_cloud9.Ec2EnvironmentProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "vpc": "vpc",
+        "cloned_repositories": "clonedRepositories",
+        "description": "description",
+        "ec2_environment_name": "ec2EnvironmentName",
+        "instance_type": "instanceType",
+        "subnet_selection": "subnetSelection",
+    },
+)
+class Ec2EnvironmentProps:
+    def __init__(
+        self,
+        *,
+        vpc: _IVpc_3795853f,
+        cloned_repositories: typing.Optional[typing.List["CloneRepository"]] = None,
+        description: typing.Optional[str] = None,
+        ec2_environment_name: typing.Optional[str] = None,
+        instance_type: typing.Optional[_InstanceType_85a97b30] = None,
+        subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
+    ) -> None:
         """Properties for Ec2Environment.
 
         :param vpc: The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
@@ -449,15 +614,21 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        if isinstance(subnet_selection, dict): subnet_selection = _SubnetSelection_36a13cd6(**subnet_selection)
+        if isinstance(subnet_selection, dict):
+            subnet_selection = _SubnetSelection_36a13cd6(**subnet_selection)
         self._values = {
-            'vpc': vpc,
+            "vpc": vpc,
         }
-        if cloned_repositories is not None: self._values["cloned_repositories"] = cloned_repositories
-        if description is not None: self._values["description"] = description
-        if ec2_environment_name is not None: self._values["ec2_environment_name"] = ec2_environment_name
-        if instance_type is not None: self._values["instance_type"] = instance_type
-        if subnet_selection is not None: self._values["subnet_selection"] = subnet_selection
+        if cloned_repositories is not None:
+            self._values["cloned_repositories"] = cloned_repositories
+        if description is not None:
+            self._values["description"] = description
+        if ec2_environment_name is not None:
+            self._values["ec2_environment_name"] = ec2_environment_name
+        if instance_type is not None:
+            self._values["instance_type"] = instance_type
+        if subnet_selection is not None:
+            self._values["subnet_selection"] = subnet_selection
 
     @builtins.property
     def vpc(self) -> _IVpc_3795853f:
@@ -466,7 +637,7 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        return self._values.get('vpc')
+        return self._values.get("vpc")
 
     @builtins.property
     def cloned_repositories(self) -> typing.Optional[typing.List["CloneRepository"]]:
@@ -478,7 +649,7 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        return self._values.get('cloned_repositories')
+        return self._values.get("cloned_repositories")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -490,7 +661,7 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def ec2_environment_name(self) -> typing.Optional[str]:
@@ -502,7 +673,7 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        return self._values.get('ec2_environment_name')
+        return self._values.get("ec2_environment_name")
 
     @builtins.property
     def instance_type(self) -> typing.Optional[_InstanceType_85a97b30]:
@@ -514,7 +685,7 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        return self._values.get('instance_type')
+        return self._values.get("instance_type")
 
     @builtins.property
     def subnet_selection(self) -> typing.Optional[_SubnetSelection_36a13cd6]:
@@ -526,7 +697,7 @@ class Ec2EnvironmentProps():
         stability
         :stability: experimental
         """
-        return self._values.get('subnet_selection')
+        return self._values.get("subnet_selection")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -535,7 +706,9 @@ class Ec2EnvironmentProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'Ec2EnvironmentProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "Ec2EnvironmentProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_cloud9.IEc2Environment")
@@ -545,6 +718,7 @@ class IEc2Environment(_IResource_72f7ee7e, jsii.compat.Protocol):
     stability
     :stability: experimental
     """
+
     @builtins.staticmethod
     def __jsii_proxy_class__():
         return _IEc2EnvironmentProxy
@@ -580,7 +754,9 @@ class _IEc2EnvironmentProxy(jsii.proxy_for(_IResource_72f7ee7e)):
     stability
     :stability: experimental
     """
+
     __jsii_type__ = "monocdk-experiment.aws_cloud9.IEc2Environment"
+
     @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> str:
@@ -607,7 +783,11 @@ class _IEc2EnvironmentProxy(jsii.proxy_for(_IResource_72f7ee7e)):
 
 
 @jsii.implements(IEc2Environment)
-class Ec2Environment(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cloud9.Ec2Environment"):
+class Ec2Environment(
+    _Resource_884d0774,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_cloud9.Ec2Environment",
+):
     """A Cloud9 Environment with Amazon EC2.
 
     stability
@@ -615,7 +795,19 @@ class Ec2Environment(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="mon
     resource:
     :resource:: AWS::Cloud9::EnvironmentEC2
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, vpc: _IVpc_3795853f, cloned_repositories: typing.Optional[typing.List["CloneRepository"]]=None, description: typing.Optional[str]=None, ec2_environment_name: typing.Optional[str]=None, instance_type: typing.Optional[_InstanceType_85a97b30]=None, subnet_selection: typing.Optional[_SubnetSelection_36a13cd6]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        vpc: _IVpc_3795853f,
+        cloned_repositories: typing.Optional[typing.List["CloneRepository"]] = None,
+        description: typing.Optional[str] = None,
+        ec2_environment_name: typing.Optional[str] = None,
+        instance_type: typing.Optional[_InstanceType_85a97b30] = None,
+        subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -629,13 +821,22 @@ class Ec2Environment(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="mon
         stability
         :stability: experimental
         """
-        props = Ec2EnvironmentProps(vpc=vpc, cloned_repositories=cloned_repositories, description=description, ec2_environment_name=ec2_environment_name, instance_type=instance_type, subnet_selection=subnet_selection)
+        props = Ec2EnvironmentProps(
+            vpc=vpc,
+            cloned_repositories=cloned_repositories,
+            description=description,
+            ec2_environment_name=ec2_environment_name,
+            instance_type=instance_type,
+            subnet_selection=subnet_selection,
+        )
 
         jsii.create(Ec2Environment, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromEc2EnvironmentName")
     @builtins.classmethod
-    def from_ec2_environment_name(cls, scope: _Construct_f50a3f53, id: str, ec2_environment_name: str) -> "IEc2Environment":
+    def from_ec2_environment_name(
+        cls, scope: _Construct_f50a3f53, id: str, ec2_environment_name: str
+    ) -> "IEc2Environment":
         """import from EnvironmentEc2Name.
 
         :param scope: -
@@ -645,7 +846,9 @@ class Ec2Environment(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="mon
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name])
+        return jsii.sinvoke(
+            cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name]
+        )
 
     @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
