@@ -16,9 +16,9 @@ from ..aws_cloudfront import (
     OriginProtocolPolicy as _OriginProtocolPolicy_d2d28ec7,
     CfnDistribution as _CfnDistribution_3a5e7b5c,
     OriginProps as _OriginProps_3ddcc1c8,
+    IOrigin as _IOrigin_ceac1980,
     OriginBindConfig as _OriginBindConfig_86e63cf0,
     OriginBindOptions as _OriginBindOptions_5b2ffb69,
-    IOrigin as _IOrigin_ceac1980,
 )
 from ..aws_elasticloadbalancingv2 import ILoadBalancerV2 as _ILoadBalancerV2_3b69d63d
 from ..aws_s3 import IBucket as _IBucket_25bad983
@@ -532,6 +532,135 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         )
 
 
+@jsii.implements(_IOrigin_ceac1980)
+class OriginGroup(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_cloudfront_origins.OriginGroup",
+):
+    """An Origin that represents a group.
+
+    Consists of a primary Origin,
+    and a fallback Origin called when the primary returns one of the provided HTTP status codes.
+
+    stability
+    :stability: experimental
+    """
+
+    def __init__(
+        self,
+        *,
+        fallback_origin: _IOrigin_ceac1980,
+        primary_origin: _IOrigin_ceac1980,
+        fallback_status_codes: typing.Optional[typing.List[jsii.Number]] = None,
+    ) -> None:
+        """
+        :param fallback_origin: The fallback origin that should serve requests when the primary fails.
+        :param primary_origin: The primary origin that should serve requests for this group.
+        :param fallback_status_codes: The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin. Default: - 500, 502, 503 and 504
+
+        stability
+        :stability: experimental
+        """
+        props = OriginGroupProps(
+            fallback_origin=fallback_origin,
+            primary_origin=primary_origin,
+            fallback_status_codes=fallback_status_codes,
+        )
+
+        jsii.create(OriginGroup, self, [props])
+
+    @jsii.member(jsii_name="bind")
+    def bind(
+        self, scope: _Construct_f50a3f53, *, origin_id: str
+    ) -> _OriginBindConfig_86e63cf0:
+        """The method called when a given Origin is added (for the first time) to a Distribution.
+
+        :param scope: -
+        :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
+
+        stability
+        :stability: experimental
+        """
+        options = _OriginBindOptions_5b2ffb69(origin_id=origin_id)
+
+        return jsii.invoke(self, "bind", [scope, options])
+
+
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_cloudfront_origins.OriginGroupProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "fallback_origin": "fallbackOrigin",
+        "primary_origin": "primaryOrigin",
+        "fallback_status_codes": "fallbackStatusCodes",
+    },
+)
+class OriginGroupProps:
+    def __init__(
+        self,
+        *,
+        fallback_origin: _IOrigin_ceac1980,
+        primary_origin: _IOrigin_ceac1980,
+        fallback_status_codes: typing.Optional[typing.List[jsii.Number]] = None,
+    ) -> None:
+        """Construction properties for {@link OriginGroup}.
+
+        :param fallback_origin: The fallback origin that should serve requests when the primary fails.
+        :param primary_origin: The primary origin that should serve requests for this group.
+        :param fallback_status_codes: The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin. Default: - 500, 502, 503 and 504
+
+        stability
+        :stability: experimental
+        """
+        self._values = {
+            "fallback_origin": fallback_origin,
+            "primary_origin": primary_origin,
+        }
+        if fallback_status_codes is not None:
+            self._values["fallback_status_codes"] = fallback_status_codes
+
+    @builtins.property
+    def fallback_origin(self) -> _IOrigin_ceac1980:
+        """The fallback origin that should serve requests when the primary fails.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("fallback_origin")
+
+    @builtins.property
+    def primary_origin(self) -> _IOrigin_ceac1980:
+        """The primary origin that should serve requests for this group.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("primary_origin")
+
+    @builtins.property
+    def fallback_status_codes(self) -> typing.Optional[typing.List[jsii.Number]]:
+        """The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin.
+
+        default
+        :default: - 500, 502, 503 and 504
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("fallback_status_codes")
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "OriginGroupProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(_IOrigin_ceac1980)
 class S3Origin(
     metaclass=jsii.JSIIMeta,
@@ -627,6 +756,8 @@ __all__ = [
     "HttpOriginProps",
     "LoadBalancerV2Origin",
     "LoadBalancerV2OriginProps",
+    "OriginGroup",
+    "OriginGroupProps",
     "S3Origin",
     "S3OriginProps",
 ]
