@@ -10,11 +10,24 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_codestarnotifications.CfnNotificationRule"):
+class CfnNotificationRule(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_codestarnotifications.CfnNotificationRule",
+):
     """A CloudFormation ``AWS::CodeStarNotifications::NotificationRule``.
 
     see
@@ -22,7 +35,23 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
     cloudformationResource:
     :cloudformationResource:: AWS::CodeStarNotifications::NotificationRule
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, detail_type: str, event_type_ids: typing.List[str], name: str, resource: str, targets: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]]], status: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        detail_type: str,
+        event_type_ids: typing.List[str],
+        name: str,
+        resource: str,
+        targets: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]],
+        ],
+        status: typing.Optional[str] = None,
+        tags: typing.Any = None,
+    ) -> None:
         """Create a new ``AWS::CodeStarNotifications::NotificationRule``.
 
         :param scope: - scope in which this resource is defined.
@@ -35,13 +64,28 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         :param status: ``AWS::CodeStarNotifications::NotificationRule.Status``.
         :param tags: ``AWS::CodeStarNotifications::NotificationRule.Tags``.
         """
-        props = CfnNotificationRuleProps(detail_type=detail_type, event_type_ids=event_type_ids, name=name, resource=resource, targets=targets, status=status, tags=tags)
+        props = CfnNotificationRuleProps(
+            detail_type=detail_type,
+            event_type_ids=event_type_ids,
+            name=name,
+            resource=resource,
+            targets=targets,
+            status=status,
+            tags=tags,
+        )
 
         jsii.create(CfnNotificationRule, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnNotificationRule":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnNotificationRule":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -56,7 +100,9 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -70,7 +116,9 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -155,7 +203,12 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
 
     @builtins.property
     @jsii.member(jsii_name="targets")
-    def targets(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]]]:
+    def targets(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]],
+    ]:
         """``AWS::CodeStarNotifications::NotificationRule.Targets``.
 
         see
@@ -164,7 +217,13 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "targets")
 
     @targets.setter
-    def targets(self, value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]]]) -> None:
+    def targets(
+        self,
+        value: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["TargetProperty", _IResolvable_9ceae33e]],
+        ],
+    ) -> None:
         jsii.set(self, "targets", value)
 
     @builtins.property
@@ -181,9 +240,18 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
     def status(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "status", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_codestarnotifications.CfnNotificationRule.TargetProperty", jsii_struct_bases=[], name_mapping={'target_address': 'targetAddress', 'target_type': 'targetType'})
-    class TargetProperty():
-        def __init__(self, *, target_address: typing.Optional[str]=None, target_type: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_codestarnotifications.CfnNotificationRule.TargetProperty",
+        jsii_struct_bases=[],
+        name_mapping={"target_address": "targetAddress", "target_type": "targetType"},
+    )
+    class TargetProperty:
+        def __init__(
+            self,
+            *,
+            target_address: typing.Optional[str] = None,
+            target_type: typing.Optional[str] = None,
+        ) -> None:
             """
             :param target_address: ``CfnNotificationRule.TargetProperty.TargetAddress``.
             :param target_type: ``CfnNotificationRule.TargetProperty.TargetType``.
@@ -191,10 +259,11 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestarnotifications-notificationrule-target.html
             """
-            self._values = {
-            }
-            if target_address is not None: self._values["target_address"] = target_address
-            if target_type is not None: self._values["target_type"] = target_type
+            self._values = {}
+            if target_address is not None:
+                self._values["target_address"] = target_address
+            if target_type is not None:
+                self._values["target_type"] = target_type
 
         @builtins.property
         def target_address(self) -> typing.Optional[str]:
@@ -203,7 +272,7 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestarnotifications-notificationrule-target.html#cfn-codestarnotifications-notificationrule-target-targetaddress
             """
-            return self._values.get('target_address')
+            return self._values.get("target_address")
 
         @builtins.property
         def target_type(self) -> typing.Optional[str]:
@@ -212,7 +281,7 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestarnotifications-notificationrule-target.html#cfn-codestarnotifications-notificationrule-target-targettype
             """
-            return self._values.get('target_type')
+            return self._values.get("target_type")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -221,13 +290,43 @@ class CfnNotificationRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'TargetProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "TargetProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_codestarnotifications.CfnNotificationRuleProps", jsii_struct_bases=[], name_mapping={'detail_type': 'detailType', 'event_type_ids': 'eventTypeIds', 'name': 'name', 'resource': 'resource', 'targets': 'targets', 'status': 'status', 'tags': 'tags'})
-class CfnNotificationRuleProps():
-    def __init__(self, *, detail_type: str, event_type_ids: typing.List[str], name: str, resource: str, targets: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_9ceae33e]]], status: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_codestarnotifications.CfnNotificationRuleProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "detail_type": "detailType",
+        "event_type_ids": "eventTypeIds",
+        "name": "name",
+        "resource": "resource",
+        "targets": "targets",
+        "status": "status",
+        "tags": "tags",
+    },
+)
+class CfnNotificationRuleProps:
+    def __init__(
+        self,
+        *,
+        detail_type: str,
+        event_type_ids: typing.List[str],
+        name: str,
+        resource: str,
+        targets: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union[
+                    "CfnNotificationRule.TargetProperty", _IResolvable_9ceae33e
+                ]
+            ],
+        ],
+        status: typing.Optional[str] = None,
+        tags: typing.Any = None,
+    ) -> None:
         """Properties for defining a ``AWS::CodeStarNotifications::NotificationRule``.
 
         :param detail_type: ``AWS::CodeStarNotifications::NotificationRule.DetailType``.
@@ -242,14 +341,16 @@ class CfnNotificationRuleProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html
         """
         self._values = {
-            'detail_type': detail_type,
-            'event_type_ids': event_type_ids,
-            'name': name,
-            'resource': resource,
-            'targets': targets,
+            "detail_type": detail_type,
+            "event_type_ids": event_type_ids,
+            "name": name,
+            "resource": resource,
+            "targets": targets,
         }
-        if status is not None: self._values["status"] = status
-        if tags is not None: self._values["tags"] = tags
+        if status is not None:
+            self._values["status"] = status
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def detail_type(self) -> str:
@@ -258,7 +359,7 @@ class CfnNotificationRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-detailtype
         """
-        return self._values.get('detail_type')
+        return self._values.get("detail_type")
 
     @builtins.property
     def event_type_ids(self) -> typing.List[str]:
@@ -267,7 +368,7 @@ class CfnNotificationRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         """
-        return self._values.get('event_type_ids')
+        return self._values.get("event_type_ids")
 
     @builtins.property
     def name(self) -> str:
@@ -276,7 +377,7 @@ class CfnNotificationRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def resource(self) -> str:
@@ -285,16 +386,23 @@ class CfnNotificationRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-resource
         """
-        return self._values.get('resource')
+        return self._values.get("resource")
 
     @builtins.property
-    def targets(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_9ceae33e]]]:
+    def targets(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[
+            typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_9ceae33e]
+        ],
+    ]:
         """``AWS::CodeStarNotifications::NotificationRule.Targets``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         """
-        return self._values.get('targets')
+        return self._values.get("targets")
 
     @builtins.property
     def status(self) -> typing.Optional[str]:
@@ -303,7 +411,7 @@ class CfnNotificationRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-status
         """
-        return self._values.get('status')
+        return self._values.get("status")
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -312,7 +420,7 @@ class CfnNotificationRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -321,7 +429,9 @@ class CfnNotificationRuleProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnNotificationRuleProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnNotificationRuleProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
