@@ -1879,6 +1879,18 @@ class Repository(
         """
         return jsii.invoke(self, "addToResourcePolicy", [statement])
 
+    @jsii.member(jsii_name="validate")
+    def _validate(self) -> typing.List[str]:
+        """Validate the current construct.
+
+        This method can be implemented by derived constructs in order to perform
+        validation logic. It is called on all constructs before synthesis.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "validate", [])
+
     @builtins.property
     @jsii.member(jsii_name="repositoryArn")
     def repository_arn(self) -> str:
