@@ -23,6 +23,7 @@ from .. import (
     IInspectable as _IInspectable_051e6ed8,
     IResource as _IResource_72f7ee7e,
 )
+from ..aws_ec2 import ISecurityGroup as _ISecurityGroup_d72ab8e8, IVpc as _IVpc_3795853f
 
 
 @jsii.data_type(
@@ -137,6 +138,45 @@ class AcceleratorProps:
         )
 
 
+class AcceleratorSecurityGroup(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_globalaccelerator.AcceleratorSecurityGroup",
+):
+    """The security group used by a Global Accelerator to send traffic to resources in a VPC.
+
+    stability
+    :stability: experimental
+    """
+
+    @jsii.member(jsii_name="fromVpc")
+    @builtins.classmethod
+    def from_vpc(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        vpc: _IVpc_3795853f,
+        endpoint_group: "EndpointGroup",
+    ) -> _ISecurityGroup_d72ab8e8:
+        """Lookup the Global Accelerator security group at CloudFormation deployment time.
+
+        As of this writing, Global Accelerators (AGA) create a single security group per VPC. AGA security groups are shared
+        by all AGAs in an account. Additionally, there is no CloudFormation mechanism to reference the AGA security groups.
+
+        This makes creating security group rules which allow traffic from an AGA complicated in CDK. This lookup will identify
+        the AGA security group for a given VPC at CloudFormation deployment time, and lets you create rules for traffic from AGA
+        to other resources created by CDK.
+
+        :param scope: -
+        :param id: -
+        :param vpc: -
+        :param endpoint_group: -
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromVpc", [scope, id, vpc, endpoint_group])
+
+
 @jsii.implements(_IInspectable_051e6ed8)
 class CfnAccelerator(
     _CfnResource_7760e8e4,
@@ -2450,6 +2490,7 @@ __all__ = [
     "Accelerator",
     "AcceleratorAttributes",
     "AcceleratorProps",
+    "AcceleratorSecurityGroup",
     "CfnAccelerator",
     "CfnAcceleratorProps",
     "CfnEndpointGroup",
