@@ -10,11 +10,23 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnDevice(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_iot1click.CfnDevice"):
+class CfnDevice(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_iot1click.CfnDevice",
+):
     """A CloudFormation ``AWS::IoT1Click::Device``.
 
     see
@@ -22,7 +34,15 @@ class CfnDevice(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     cloudformationResource:
     :cloudformationResource:: AWS::IoT1Click::Device
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, device_id: str, enabled: typing.Union[bool, _IResolvable_9ceae33e]) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        device_id: str,
+        enabled: typing.Union[bool, _IResolvable_9ceae33e],
+    ) -> None:
         """Create a new ``AWS::IoT1Click::Device``.
 
         :param scope: - scope in which this resource is defined.
@@ -36,7 +56,14 @@ class CfnDevice(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnDevice":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnDevice":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -51,7 +78,9 @@ class CfnDevice(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -65,7 +94,9 @@ class CfnDevice(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -138,9 +169,15 @@ class CfnDevice(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         jsii.set(self, "enabled", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_iot1click.CfnDeviceProps", jsii_struct_bases=[], name_mapping={'device_id': 'deviceId', 'enabled': 'enabled'})
-class CfnDeviceProps():
-    def __init__(self, *, device_id: str, enabled: typing.Union[bool, _IResolvable_9ceae33e]) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_iot1click.CfnDeviceProps",
+    jsii_struct_bases=[],
+    name_mapping={"device_id": "deviceId", "enabled": "enabled"},
+)
+class CfnDeviceProps:
+    def __init__(
+        self, *, device_id: str, enabled: typing.Union[bool, _IResolvable_9ceae33e]
+    ) -> None:
         """Properties for defining a ``AWS::IoT1Click::Device``.
 
         :param device_id: ``AWS::IoT1Click::Device.DeviceId``.
@@ -150,8 +187,8 @@ class CfnDeviceProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html
         """
         self._values = {
-            'device_id': device_id,
-            'enabled': enabled,
+            "device_id": device_id,
+            "enabled": enabled,
         }
 
     @builtins.property
@@ -161,7 +198,7 @@ class CfnDeviceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-deviceid
         """
-        return self._values.get('device_id')
+        return self._values.get("device_id")
 
     @builtins.property
     def enabled(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
@@ -170,7 +207,7 @@ class CfnDeviceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-enabled
         """
-        return self._values.get('enabled')
+        return self._values.get("enabled")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -179,11 +216,17 @@ class CfnDeviceProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnDeviceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnDeviceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnPlacement(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_iot1click.CfnPlacement"):
+class CfnPlacement(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_iot1click.CfnPlacement",
+):
     """A CloudFormation ``AWS::IoT1Click::Placement``.
 
     see
@@ -191,7 +234,17 @@ class CfnPlacement(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
     cloudformationResource:
     :cloudformationResource:: AWS::IoT1Click::Placement
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, project_name: str, associated_devices: typing.Any=None, attributes: typing.Any=None, placement_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        project_name: str,
+        associated_devices: typing.Any = None,
+        attributes: typing.Any = None,
+        placement_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::IoT1Click::Placement``.
 
         :param scope: - scope in which this resource is defined.
@@ -201,13 +254,25 @@ class CfnPlacement(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         :param attributes: ``AWS::IoT1Click::Placement.Attributes``.
         :param placement_name: ``AWS::IoT1Click::Placement.PlacementName``.
         """
-        props = CfnPlacementProps(project_name=project_name, associated_devices=associated_devices, attributes=attributes, placement_name=placement_name)
+        props = CfnPlacementProps(
+            project_name=project_name,
+            associated_devices=associated_devices,
+            attributes=attributes,
+            placement_name=placement_name,
+        )
 
         jsii.create(CfnPlacement, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnPlacement":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnPlacement":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -222,7 +287,9 @@ class CfnPlacement(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -236,7 +303,9 @@ class CfnPlacement(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -328,9 +397,25 @@ class CfnPlacement(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         jsii.set(self, "placementName", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_iot1click.CfnPlacementProps", jsii_struct_bases=[], name_mapping={'project_name': 'projectName', 'associated_devices': 'associatedDevices', 'attributes': 'attributes', 'placement_name': 'placementName'})
-class CfnPlacementProps():
-    def __init__(self, *, project_name: str, associated_devices: typing.Any=None, attributes: typing.Any=None, placement_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_iot1click.CfnPlacementProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "project_name": "projectName",
+        "associated_devices": "associatedDevices",
+        "attributes": "attributes",
+        "placement_name": "placementName",
+    },
+)
+class CfnPlacementProps:
+    def __init__(
+        self,
+        *,
+        project_name: str,
+        associated_devices: typing.Any = None,
+        attributes: typing.Any = None,
+        placement_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::IoT1Click::Placement``.
 
         :param project_name: ``AWS::IoT1Click::Placement.ProjectName``.
@@ -342,11 +427,14 @@ class CfnPlacementProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html
         """
         self._values = {
-            'project_name': project_name,
+            "project_name": project_name,
         }
-        if associated_devices is not None: self._values["associated_devices"] = associated_devices
-        if attributes is not None: self._values["attributes"] = attributes
-        if placement_name is not None: self._values["placement_name"] = placement_name
+        if associated_devices is not None:
+            self._values["associated_devices"] = associated_devices
+        if attributes is not None:
+            self._values["attributes"] = attributes
+        if placement_name is not None:
+            self._values["placement_name"] = placement_name
 
     @builtins.property
     def project_name(self) -> str:
@@ -355,7 +443,7 @@ class CfnPlacementProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-projectname
         """
-        return self._values.get('project_name')
+        return self._values.get("project_name")
 
     @builtins.property
     def associated_devices(self) -> typing.Any:
@@ -364,7 +452,7 @@ class CfnPlacementProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-associateddevices
         """
-        return self._values.get('associated_devices')
+        return self._values.get("associated_devices")
 
     @builtins.property
     def attributes(self) -> typing.Any:
@@ -373,7 +461,7 @@ class CfnPlacementProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-attributes
         """
-        return self._values.get('attributes')
+        return self._values.get("attributes")
 
     @builtins.property
     def placement_name(self) -> typing.Optional[str]:
@@ -382,7 +470,7 @@ class CfnPlacementProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-placementname
         """
-        return self._values.get('placement_name')
+        return self._values.get("placement_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -391,11 +479,17 @@ class CfnPlacementProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnPlacementProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnPlacementProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_iot1click.CfnProject"):
+class CfnProject(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_iot1click.CfnProject",
+):
     """A CloudFormation ``AWS::IoT1Click::Project``.
 
     see
@@ -403,7 +497,18 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
     cloudformationResource:
     :cloudformationResource:: AWS::IoT1Click::Project
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, placement_template: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e], description: typing.Optional[str]=None, project_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        placement_template: typing.Union[
+            "PlacementTemplateProperty", _IResolvable_9ceae33e
+        ],
+        description: typing.Optional[str] = None,
+        project_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::IoT1Click::Project``.
 
         :param scope: - scope in which this resource is defined.
@@ -412,13 +517,24 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
         :param description: ``AWS::IoT1Click::Project.Description``.
         :param project_name: ``AWS::IoT1Click::Project.ProjectName``.
         """
-        props = CfnProjectProps(placement_template=placement_template, description=description, project_name=project_name)
+        props = CfnProjectProps(
+            placement_template=placement_template,
+            description=description,
+            project_name=project_name,
+        )
 
         jsii.create(CfnProject, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnProject":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnProject":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -433,7 +549,9 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -447,7 +565,9 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -484,7 +604,9 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
 
     @builtins.property
     @jsii.member(jsii_name="placementTemplate")
-    def placement_template(self) -> typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e]:
+    def placement_template(
+        self,
+    ) -> typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Project.PlacementTemplate``.
 
         see
@@ -493,7 +615,9 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
         return jsii.get(self, "placementTemplate")
 
     @placement_template.setter
-    def placement_template(self, value: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e]) -> None:
+    def placement_template(
+        self, value: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "placementTemplate", value)
 
     @builtins.property
@@ -524,9 +648,21 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
     def project_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "projectName", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_iot1click.CfnProject.DeviceTemplateProperty", jsii_struct_bases=[], name_mapping={'callback_overrides': 'callbackOverrides', 'device_type': 'deviceType'})
-    class DeviceTemplateProperty():
-        def __init__(self, *, callback_overrides: typing.Any=None, device_type: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_iot1click.CfnProject.DeviceTemplateProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "callback_overrides": "callbackOverrides",
+            "device_type": "deviceType",
+        },
+    )
+    class DeviceTemplateProperty:
+        def __init__(
+            self,
+            *,
+            callback_overrides: typing.Any = None,
+            device_type: typing.Optional[str] = None,
+        ) -> None:
             """
             :param callback_overrides: ``CfnProject.DeviceTemplateProperty.CallbackOverrides``.
             :param device_type: ``CfnProject.DeviceTemplateProperty.DeviceType``.
@@ -534,10 +670,11 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html
             """
-            self._values = {
-            }
-            if callback_overrides is not None: self._values["callback_overrides"] = callback_overrides
-            if device_type is not None: self._values["device_type"] = device_type
+            self._values = {}
+            if callback_overrides is not None:
+                self._values["callback_overrides"] = callback_overrides
+            if device_type is not None:
+                self._values["device_type"] = device_type
 
         @builtins.property
         def callback_overrides(self) -> typing.Any:
@@ -546,7 +683,7 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html#cfn-iot1click-project-devicetemplate-callbackoverrides
             """
-            return self._values.get('callback_overrides')
+            return self._values.get("callback_overrides")
 
         @builtins.property
         def device_type(self) -> typing.Optional[str]:
@@ -555,7 +692,7 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html#cfn-iot1click-project-devicetemplate-devicetype
             """
-            return self._values.get('device_type')
+            return self._values.get("device_type")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -564,12 +701,35 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'DeviceTemplateProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "DeviceTemplateProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_iot1click.CfnProject.PlacementTemplateProperty", jsii_struct_bases=[], name_mapping={'default_attributes': 'defaultAttributes', 'device_templates': 'deviceTemplates'})
-    class PlacementTemplateProperty():
-        def __init__(self, *, default_attributes: typing.Any=None, device_templates: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_iot1click.CfnProject.PlacementTemplateProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "default_attributes": "defaultAttributes",
+            "device_templates": "deviceTemplates",
+        },
+    )
+    class PlacementTemplateProperty:
+        def __init__(
+            self,
+            *,
+            default_attributes: typing.Any = None,
+            device_templates: typing.Optional[
+                typing.Union[
+                    _IResolvable_9ceae33e,
+                    typing.Mapping[
+                        str,
+                        typing.Union[
+                            "CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e
+                        ],
+                    ],
+                ]
+            ] = None,
+        ) -> None:
             """
             :param default_attributes: ``CfnProject.PlacementTemplateProperty.DefaultAttributes``.
             :param device_templates: ``CfnProject.PlacementTemplateProperty.DeviceTemplates``.
@@ -577,10 +737,11 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html
             """
-            self._values = {
-            }
-            if default_attributes is not None: self._values["default_attributes"] = default_attributes
-            if device_templates is not None: self._values["device_templates"] = device_templates
+            self._values = {}
+            if default_attributes is not None:
+                self._values["default_attributes"] = default_attributes
+            if device_templates is not None:
+                self._values["device_templates"] = device_templates
 
         @builtins.property
         def default_attributes(self) -> typing.Any:
@@ -589,16 +750,28 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html#cfn-iot1click-project-placementtemplate-defaultattributes
             """
-            return self._values.get('default_attributes')
+            return self._values.get("default_attributes")
 
         @builtins.property
-        def device_templates(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]]:
+        def device_templates(
+            self,
+        ) -> typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.Mapping[
+                    str,
+                    typing.Union[
+                        "CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e
+                    ],
+                ],
+            ]
+        ]:
             """``CfnProject.PlacementTemplateProperty.DeviceTemplates``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html#cfn-iot1click-project-placementtemplate-devicetemplates
             """
-            return self._values.get('device_templates')
+            return self._values.get("device_templates")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -607,13 +780,30 @@ class CfnProject(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mono
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'PlacementTemplateProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "PlacementTemplateProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_iot1click.CfnProjectProps", jsii_struct_bases=[], name_mapping={'placement_template': 'placementTemplate', 'description': 'description', 'project_name': 'projectName'})
-class CfnProjectProps():
-    def __init__(self, *, placement_template: typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e], description: typing.Optional[str]=None, project_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_iot1click.CfnProjectProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "placement_template": "placementTemplate",
+        "description": "description",
+        "project_name": "projectName",
+    },
+)
+class CfnProjectProps:
+    def __init__(
+        self,
+        *,
+        placement_template: typing.Union[
+            "CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e
+        ],
+        description: typing.Optional[str] = None,
+        project_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::IoT1Click::Project``.
 
         :param placement_template: ``AWS::IoT1Click::Project.PlacementTemplate``.
@@ -624,19 +814,23 @@ class CfnProjectProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html
         """
         self._values = {
-            'placement_template': placement_template,
+            "placement_template": placement_template,
         }
-        if description is not None: self._values["description"] = description
-        if project_name is not None: self._values["project_name"] = project_name
+        if description is not None:
+            self._values["description"] = description
+        if project_name is not None:
+            self._values["project_name"] = project_name
 
     @builtins.property
-    def placement_template(self) -> typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e]:
+    def placement_template(
+        self,
+    ) -> typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Project.PlacementTemplate``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-placementtemplate
         """
-        return self._values.get('placement_template')
+        return self._values.get("placement_template")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -645,7 +839,7 @@ class CfnProjectProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def project_name(self) -> typing.Optional[str]:
@@ -654,7 +848,7 @@ class CfnProjectProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-projectname
         """
-        return self._values.get('project_name')
+        return self._values.get("project_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -663,7 +857,9 @@ class CfnProjectProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnProjectProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnProjectProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
