@@ -1055,6 +1055,18 @@ class Key(
         """
         return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
 
+    @jsii.member(jsii_name="validate")
+    def _validate(self) -> typing.List[str]:
+        """Validate the current construct.
+
+        This method can be implemented by derived constructs in order to perform
+        validation logic. It is called on all constructs before synthesis.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "validate", [])
+
     @builtins.property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
